@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.505";
+our $VERSION = "0.506";
 
 1;
 
@@ -10,13 +10,7 @@ SPVM::Sys - System Calls for File IO, Sockets, Time, Process, Signals, Users
 
 =head1 Description
 
-C<SPVM::Sys> is the C<Sys> class in L<SPVM> language. It provides system calls such as file IO, user manipulation, process, socket, time,
-
-This class provides methods compatible with functions related to system calls provided by Perl.
-
-This distribution contains many modules for system calls such as L<Sys::IO|SPVM::Sys::IO>, L<Sys::Socket|SPVM::Sys::Socket>, L<Sys::Process|SPVM::Sys::Process>. See L</"Modules">.
-
-Methods compatible with file IO, sockets, file paths, current directory, select, and poll are implemented as other modules such as L<IO::File|SPVM::IO::File>, L<IO::Socket|SPVM::IO::Socket>, L<Cwd|SPVM::Cwd>. See L</"See Also">.
+The Sys class of L<SPVM> has methods to call system calls for file IO, sockets, user manipulation, process manipulation, and time.
 
 =head1 Usage
 
@@ -438,12 +432,6 @@ C<static method gmtime : L<Sys::Time::Tm|SPVM::Sys::Time::Tm> ($time : long);>
 
 Works just like L</"localtime">, but the returned values are localized for the standard Greenwich time zone.
 
-=head2 process_id
-
-C<static method process_id : int ();>
-
-Gets the process number of the running this program. The same as the Perl L<$$|https://perldoc.perl.org/perlvar#$PROCESS_ID>.
-
 =head2 stat
 
 C<static method stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat> ($path : string);>
@@ -464,31 +452,31 @@ And returns the a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
 C<static method chdir : void ($path : string);>
 
-Changes the working directory to $path. The same as the Perl L<chdir|https://perldoc.perl.org/functions/chdir> function.
+Changes the working directory to $path.
 
 =head2 chmod
 
 C<static method chmod : void ($mode :int, $path : string);>
 
-Changes the permissions of a file. The same as the Perl L<chmod|https://perldoc.perl.org/functions/chmod> function.
+Changes the permissions of a file.
 
 =head2 mkdir
 
 C<static method mkdir : void ($path : string, $mode : int);>
 
-Creates the directory specified by $path and $mode. The same as the Perl L<mkdir|https://perldoc.perl.org/functions/mkdir> function.
+Creates the directory specified by $path and $mode.
 
 =head2 umask
 
 C<static method umask : int ($mode : int);>
 
-Sets the umask for the process to $mode and returns the previous value. The same as the Perl L<umask|https://perldoc.perl.org/functions/umask> function.
+Sets the umask for the process to $mode and returns the previous value.
 
 =head2 rmdir
 
 C<static method rmdir : void ($path : string);>
 
-Deletes the directory specified by $path. The same as the Perl L<rmdir|https://perldoc.perl.org/functions/rmdir> function.
+Deletes the directory specified by $path.
 
 =head2 opendir
 
@@ -516,31 +504,31 @@ If succedd, returns 1.
 
 C<static method unlink : void ($pathname : string);>
 
-Deletes a file. The same as the Perl L<unlink|https://perldoc.perl.org/functions/unlink> function.
+Deletes a file.
 
 =head2 rename
 
 C<static method rename : void ($oldpath : string, $newpath : string);>
 
-Changes the name of a file. The same as the Perl L<rename|https://perldoc.perl.org/functions/rename> function.
+Changes the name of a file.
 
 =head2 readlink
 
 C<static method readlink : int ($file : string);>
 
-Returns the value of a symbolic link. The same as the Perl L<readlink|https://perldoc.perl.org/functions/readlink> function.
+Returns the value of a symbolic link.
 
 =head2 symlink
 
 C<static method symlink : int ($oldpath : string, $newpath : string);>
 
-Creates a $newpath symbolically linked to $oldpath. The same as the Perl L<symlink|https://perldoc.perl.org/functions/symlink> function.
+Creates a $newpath symbolically linked to $oldpath.
 
 =head2 sleep
 
 C<static method sleep : int ($seconds : int);>
 
-Causes the program to sleep for $seconds seconds. The same as the Perl L<sleep|https://perldoc.perl.org/functions/sleep>.
+Causes the program to sleep for $seconds seconds.
 
 =head2 ioctl
 
@@ -959,6 +947,112 @@ Exceptions:
 
 The exceptions thrown by the L<alarm|SPVM::Sys::Signal/"alarm"> method in the Sys::Signal class could be thrown.
 
+=head2 popen
+
+C<static method popen : void ($stream_ref : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>[], $open_mode : string, $command : string);>
+
+=head2 pclose
+
+C<static method pclose : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+=head2 fork
+
+C<static method fork : int ();>
+
+Forks the process by calling the L<fork|SPVM::Sys::Process/"fork"> method in the Sys::Process method.
+
+It returns the child process ID to the parent process, or returns 0 to the child process.
+
+Excetpions:
+
+Exceptions thrown by the L<fork|SPVM::Sys::Process/"fork"> method in the Sys::Process method could be thrown.
+
+=head2 getpriority
+
+C<static method getpriority : int ($which : int, $who : int);>
+
+Return the scheduling priority of the process, process group, or user, as indicated by $which and $who is obtained.
+
+Excetpions:
+
+Exceptions thrown by the L<getpriority|SPVM::Sys::Process/"getpriority"> method in the Sys::Process method could be thrown.
+
+=head2 setpriority
+
+C<static method setpriority : void ($which : int, $who : int, $prio : int)>
+
+Sets the scheduling priority of the process, process group, or user, as indicated by $which and $who is obtained.
+
+Excetpions:
+
+Exceptions thrown by the L<setpriority|SPVM::Sys::Process/"setpriority"> method in the Sys::Process method could be thrown.
+
+=head2 sleep
+
+C<static method sleep : int ($seconds : int);>
+
+Sleeps for the seconds $seconds.
+
+=head2 wait
+
+C<static method wait : int ($wstatus_ref : int*);>
+
+Waits for state changes in a child of the calling process, and returns a process ID whose state is changed.
+
+The status about the child whose state has changed is set to $wstatus_ref.
+
+The following method in the Sys::Process class checks the value of $wstatus_ref.
+
+=over 2
+
+=item * L<WIFEXITED|SPVM::Sys::Process/"WIFEXITED">
+
+=item * L<WEXITSTATUS|SPVM::Sys::Process/"WEXITSTATUS">
+
+=item * L<WIFSIGNALED|SPVM::Sys::Process/"WIFSIGNALED">
+
+=item * L<WTERMSIG|SPVM::Sys::Process/"WTERMSIG">
+
+=item * L<WCOREDUMP|SPVM::Sys::Process/"WCOREDUMP">
+
+=item * L<WIFEXITED|SPVM::Sys::Process/"WIFEXITED">
+
+=item * L<WIFSTOPPED|SPVM::Sys::Process/"WIFSTOPPED">
+
+=item * L<WSTOPSIG|SPVM::Sys::Process/"WSTOPSIG">
+
+=item * L<WIFCONTINUED|SPVM::Sys::Process/"WIFCONTINUED">
+
+=back
+
+Excetpions:
+
+Exceptions thrown by the L<wait|SPVM::Sys::Process/"wait"> method in the Sys::Process method could be thrown.
+
+=head2 waitpid
+
+C<static method waitpid : int ($pid : in, $options : int, $wstatus_ref : int*);>
+
+Same as the L</"wait"> method, but can give the process ID $pid and the options $options.
+
+See L<Sys::Process::Constant|SPVM::Sys::Process::Constant> about constant values given to $options.
+
+Excetpions:
+
+Exceptions thrown by the L<waitpid|SPVM::Sys::Process/"waitpid"> method in the Sys::Process method could be thrown.
+
+=head2 system
+
+C<static method system : int ($command : string);>
+
+Executes a command specified in command using shell and return the L</"wait"> status.
+
+=head2 exit
+
+C<static method exit : void ($status : int);>
+
+Terminates the calling process immediately with the status $status.
+
 =head2 pipe
 
 C<static method pipe : void ($read_fd_ref : int*, $write_fd_ref : int*);>
@@ -967,6 +1061,40 @@ Opens a pair of pipes.
 
 If the system supports C<FD_CLOEXEC>, this flag is set to $read_fd_ref and $write_fd_ref using L</"fcntl">.
 
+=head2 getpgrp
+
+C<static method getpgrp : int ($pid : int);>
+
+Gets the process group number given the process ID $pid of the running this program.
+
+=head2 setpgrp
+
+C<static method setpgrp : void ($pid : int, $pgid : int);>
+
+Sets the process group number $pgid given the process ID $pid of the running this program.
+
+=head2 process_id
+
+C<static method process_id : int ();>
+
+Gets the process number of the running this program.
+
+=head2 getppid
+
+C<static method getppid : int ();>
+
+Returns the process ID of the parent of the calling process.
+
+=head2 exec
+
+C<static method exec : void ($program : string, $args : string[] = undef);>
+
+Executes the program $program with the arguments $args without using shell and never returns.
+
+Examples:
+
+  Sys->exec("/bin/echo", ["-n", "Hello"]);
+
 =head1 Modules
 
 =over 2
@@ -1091,8 +1219,20 @@ If the system supports C<FD_CLOEXEC>, this flag is set to $read_fd_ref and $writ
 
 =item * L<File::Spec|SPVM::File::Spec>
 
+=item * L<File::Temp|SPVM::File::Temp>
+
+=item * L<File::Copy|SPVM::File::Copy>
+
+=item * L<File::Find|SPVM::File::Find>
+
+=item * L<File::Glob|SPVM::File::Glob>
+
 =item * L<Cwd|SPVM::Cwd>
 
+=item * L<Time::HiRes|SPVM::Time::HiRes>
+
+=item * L<Go|SPVM::Go>
+
 =back
 
 =head1 Repository
@@ -1112,4 +1252,3 @@ Gabor Szabo(L<https://github.com/szabgab>)
 Copyright (c) 2023 Yuki Kimoto
 
 MIT License
-
