@@ -66,7 +66,6 @@ int32_t SPVM__Sys__IO__INIT_STDERR(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
-  
   env->set_field_byte_by_name(env, stack, obj_stream, "no_close", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
@@ -153,7 +152,6 @@ int32_t SPVM__Sys__IO__open(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   const char* path = env->get_chars(env, stack, obj_path);
   
-  errno = 0;
   int32_t fd = open(path, flags, mode);
   if (fd == -1) {
     env->die(env, stack, "[System Error]open failed:%s. The \"%s\" file can't be opend", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
@@ -188,7 +186,6 @@ int32_t SPVM__Sys__IO__read(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "$count must be less than the length of $buf - $buf_offset.", __func__, FILE_NAME, __LINE__);
   }
   
-  errno = 0;
   int32_t read_length = read(fd, buf + buf_offset, count);
   if (read_length == -1) {
     env->die(env, stack, "[System Error]read failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -230,7 +227,6 @@ int32_t SPVM__Sys__IO__write(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "$count must be less than the length of $buf - $buf_offset.", __func__, FILE_NAME, __LINE__);
   }
   
-  errno = 0;
   int32_t write_length = write(fd, buf + buf_offset, count);
   if (write_length == -1) {
     env->die(env, stack, "[System Error]write failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -254,7 +250,6 @@ int32_t SPVM__Sys__IO__lseek(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   int32_t whence = stack[2].ival;
 
-  errno = 0;
   int64_t cur_offset = lseek(fd, offset, whence);
   if (cur_offset == -1) {
     env->die(env, stack, "[System Error]lseek failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -271,7 +266,6 @@ int32_t SPVM__Sys__IO__close(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t fd = stack[0].ival;
 
-  errno = 0;
   int32_t status = close(fd);
   if (status == -1) {
     env->die(env, stack, "[System Error]close failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -301,7 +295,6 @@ int32_t SPVM__Sys__IO__fopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = fopen(path, mode);
   
-  errno = 0;
   if (!stream) {
     env->die(env, stack, "[System Error]fopen failed:%s. The \"%s\" file can't be opend", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
@@ -333,7 +326,6 @@ int32_t SPVM__Sys__IO__fdopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   const char* mode = env->get_chars(env, stack, obj_mode);
   
-  errno = 0;
   FILE* stream = fdopen(fd, mode);
   if (!stream) {
     env->die(env, stack, "[System Error]fdopen failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -358,7 +350,6 @@ int32_t SPVM__Sys__IO__fileno(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
-  errno = 0;
   int32_t fd = fileno(stream);
   if (fd == -1) {
     env->die(env, stack, "[System Error]fileno failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -572,7 +563,6 @@ int32_t SPVM__Sys__IO__fclose(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
-  errno = 0;
   int32_t status = fclose(stream);
   if (status == EOF) {
     env->die(env, stack, "[System Error]fclose failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -605,7 +595,6 @@ int32_t SPVM__Sys__IO__fseek(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   int32_t whence = stack[2].ival;
   
-  errno = 0;
   int32_t status = fseek(stream, offset, whence);
   if (status == -1) {
     env->die(env, stack, "[System Error]fseek failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -627,7 +616,6 @@ int32_t SPVM__Sys__IO__ftell(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
-  errno = 0;
   int64_t offset = ftell(stream);
   if (offset == -1) {
     env->die(env, stack, "[System Error]ftell failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -649,7 +637,6 @@ int32_t SPVM__Sys__IO__fflush(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
-  errno = 0;
   int32_t status = fflush(stream);
   if (status == EOF) {
     env->die(env, stack, "[System Error]fflush failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -671,7 +658,6 @@ int32_t SPVM__Sys__IO__flock(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   int32_t operation = stack[1].ival;
   
-  errno = 0;
   int32_t status = flock(fd, operation);
   if (status == -1) {
     env->die(env, stack, "[System Error]flock failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -693,17 +679,15 @@ int32_t SPVM__Sys__IO__mkdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   const char* path = env->get_chars(env, stack, obj_path);
-
+  
   int32_t mode = stack[1].ival;
-
-  errno = 0;
   
 #if defined(_WIN32)
   int32_t status = mkdir(path);
 #else
   int32_t status = mkdir(path, mode);
 #endif
-
+  
   if (status == -1) {
     env->die(env, stack, "[System Error]mkdir failed:%s. The \"%s\" directory can't be created", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
@@ -734,8 +718,7 @@ int32_t SPVM__Sys__IO__rmdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   const char* path = env->get_chars(env, stack, obj_path);
-
-  errno = 0;
+  
   int32_t status = rmdir(path);
   if (status == -1) {
     env->die(env, stack, "[System Error]rmdir failed:%s. The \"%s\" directory can't be removed", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
@@ -750,20 +733,19 @@ int32_t SPVM__Sys__IO__rmdir(SPVM_ENV* env, SPVM_VALUE* stack) {
 int32_t SPVM__Sys__IO__unlink(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_pathname = stack[0].oval;
-
+  
   if (!obj_pathname) {
     return env->die(env, stack, "$pathname must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* pathname = env->get_chars(env, stack, obj_pathname);
-
-  errno = 0;
+  
   int32_t status = unlink(pathname);
   if (status == -1) {
     env->die(env, stack, "[System Error]unlink failed:%s. The \"%s\" file can't be removed", env->strerror(env, stack, errno, 0), pathname, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
-
+  
   stack[0].ival = status;
   
   return 0;
@@ -780,7 +762,7 @@ int32_t SPVM__Sys__IO__rename(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   const char* oldpath = env->get_chars(env, stack, obj_oldpath);
-
+  
   void* obj_newpath = stack[1].oval;
   
   if (!obj_newpath) {
@@ -789,7 +771,6 @@ int32_t SPVM__Sys__IO__rename(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   const char* newpath = env->get_chars(env, stack, obj_newpath);
   
-  errno = 0;
   int32_t status = rename(oldpath, newpath);
   if (status == -1) {
     env->die(env, stack, "[System Error]rename failed:%s. The \"%s\" file can't be renamed to the \"%s\" file", env->strerror(env, stack, errno, 0), oldpath, newpath, __func__, FILE_NAME, __LINE__);
@@ -821,11 +802,9 @@ int32_t SPVM__Sys__IO__getcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
       return env->die(env, stack, "$size must be less than or equal to the lenght of $buf.", __func__, FILE_NAME, __LINE__);
     }
     
-    errno = 0;
     ret_buf = getcwd(buf, size);
   }
   else {
-    errno = 0;
     ret_buf = getcwd(NULL, size);
     if (ret_buf) {
       obj_buf = env->new_string(env, stack, ret_buf, strlen(ret_buf));
@@ -868,11 +847,9 @@ int32_t SPVM__Sys__IO___getdcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
       return env->die(env, stack, "$maxlen must be less than or equal to the lenght of $buffer.", __func__, FILE_NAME, __LINE__);
     }
     
-    errno = 0;
     ret_buffer = _getdcwd(drive, buffer, maxlen);
   }
   else {
-    errno = 0;
     ret_buffer = _getdcwd(drive, NULL, maxlen);
     if (ret_buffer) {
       obj_buffer = env->new_string(env, stack, ret_buffer, strlen(ret_buffer));
@@ -902,12 +879,10 @@ int32_t SPVM__Sys__IO__realpath(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (!obj_path) {
     return env->die(env, stack, "$path must be defined.", __func__, FILE_NAME, __LINE__);
   }
-
-  const char* path = env->get_chars(env, stack, obj_path);
-
-  void* obj_resolved_path = stack[1].oval;
   
-  errno = 0;
+  const char* path = env->get_chars(env, stack, obj_path);
+  
+  void* obj_resolved_path = stack[1].oval;
   
   char* ret_resolved_path;
   if (obj_resolved_path) {
@@ -950,8 +925,6 @@ int32_t SPVM__Sys__IO___fullpath(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t maxLength = stack[2].ival;
   
-  errno = 0;
-  
   char* ret_absPath;
   if (obj_absPath) {
     char* absPath = (char*)env->get_chars(env, stack, obj_absPath);
@@ -984,7 +957,6 @@ int32_t SPVM__Sys__IO__chdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   const char* path = env->get_chars(env, stack, obj_path);
   
-  errno = 0;
   int32_t status = chdir(path);
   if (status == -1) {
     env->die(env, stack, "[System Error]chdir failed:%s. The current directory can't be changed to the \"%s\" directory", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
@@ -1003,16 +975,15 @@ int32_t SPVM__Sys__IO__chmod(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "$path must be defined.", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
-
+  
   int32_t mode = stack[1].ival;
-
-  errno = 0;
+  
   int32_t status = chmod(path, mode);
   if (status == -1) {
     env->die(env, stack, "[System Error]chmod failed:%s. The permission of the \"%s\" file can't be changed", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
-
+  
   stack[0].ival = status;
   
   return 0;
@@ -1029,18 +1000,17 @@ int32_t SPVM__Sys__IO__chown(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "$path must be defined.", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
-
+  
   int32_t owner = stack[1].ival;
-
+  
   int32_t group = stack[2].ival;
-
-  errno = 0;
+  
   int32_t status = chown(path, owner, group);
   if (status == -1) {
     env->die(env, stack, "[System Error]chown failed:%s. The owner/group of the \"%s\" file can't be changed", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
-
+  
   stack[0].ival = status;
   
   return 0;
@@ -1054,13 +1024,12 @@ int32_t SPVM__Sys__IO__truncate(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "$path must be defined.", __func__, FILE_NAME, __LINE__);
   }
   const char* path = env->get_chars(env, stack, obj_path);
-
+  
   int64_t length = stack[1].lval;
   if (!(length >= 0)) {
     return env->die(env, stack, "$length must be less than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
-
-  errno = 0;
+  
   int32_t status = truncate(path, length);
   if (status == -1) {
     env->die(env, stack, "[System Error]truncate failed:%s. The \"%s\" file can't be truncated", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
@@ -1091,7 +1060,6 @@ int32_t SPVM__Sys__IO__symlink(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   const char* newpath = env->get_chars(env, stack, obj_newpath);
   
-  errno = 0;
   int32_t status = symlink(oldpath, newpath);
   if (status == -1) {
     env->die(env, stack, "[System Error]symlink failed:%s. The symbolic link from \"%s\" to \"%s\" can't be created", env->strerror(env, stack, errno, 0), oldpath, newpath, __func__, FILE_NAME, __LINE__);
@@ -1132,7 +1100,6 @@ int32_t SPVM__Sys__IO__readlink(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "$bufsiz must be less than or equal to the length of $buf.", __func__, FILE_NAME, __LINE__);
   }
   
-  errno = 0;
   int32_t placed_length = readlink(path, buf, bufsiz);
   if (placed_length == -1) {
     env->die(env, stack, "[System Error]readlink failed:%s. The reading of the symbolic link of the \"%s\" file failed", env->strerror(env, stack, errno, 0), path, __func__, FILE_NAME, __LINE__);
@@ -1154,14 +1121,13 @@ int32_t SPVM__Sys__IO__opendir(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "$dir must be defined.", __func__, FILE_NAME, __LINE__);
   }
   const char* dir = env->get_chars(env, stack, obj_dir);
-
-  errno = 0;
+  
   DIR* dir_stream = opendir(dir);
   if (!dir_stream) {
     env->die(env, stack, "[System Error]opendir failed:%s. The \"%s\" directory can't be opened", env->strerror(env, stack, errno, 0), dir, __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
-
+  
   void* obj_dir_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::DirStream", dir_stream, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
@@ -1180,16 +1146,15 @@ int32_t SPVM__Sys__IO__closedir(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
   
-  errno = 0;
   int32_t status = closedir(dirp);
   if (status == -1) {
     env->die(env, stack, "[System Error]closedir failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
-
+  
   env->set_field_byte_by_name(env, stack, obj_dirp, "closed", 1, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
-
+  
   stack[0].ival = status;
   
   return 0;
@@ -1247,7 +1212,6 @@ int32_t SPVM__Sys__IO__telldir(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
   
-  errno = 0;
   int64_t offset = telldir(dirp);
   if (offset == -1) {
     env->die(env, stack, "[System Error]telldir failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -1299,7 +1263,6 @@ int32_t SPVM__Sys__IO__utime(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_times = NULL;
   }
   
-  errno = 0;
   int32_t status = utime(filename, st_times);
   if (status == -1) {
     env->die(env, stack, "[System Error]utime failed:%s. The access and modification times of the \"%s\" file can't be changed", env->strerror(env, stack, errno, 0), filename, __func__, FILE_NAME, __LINE__);
@@ -1350,10 +1313,9 @@ int32_t SPVM__Sys__IO__faccessat(SPVM_ENV* env, SPVM_VALUE* stack) {
   const char* pathname = env->get_chars(env, stack, obj_pathname);
   
   int32_t mode = stack[2].ival;
-
+  
   int32_t flags = stack[3].ival;
   
-  errno = 0;
   int32_t status = faccessat(dirfd, pathname, mode, flags);
   
   if (status == -1) {
@@ -1420,7 +1382,6 @@ int32_t SPVM__Sys__IO__ftruncate(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int64_t length = stack[1].lval;
   
-  errno = 0;
   int32_t status = ftruncate(fd, length);
   
   if (status == -1) {
@@ -1460,7 +1421,6 @@ int32_t SPVM__Sys__IO__fsync(SPVM_ENV* env, SPVM_VALUE* stack) {
 #else
   int32_t fd = stack[0].ival;
   
-  errno = 0;
   int32_t status = fsync(fd);
   if (status == -1) {
     env->die(env, stack, "[System Error]fsync failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -1495,7 +1455,6 @@ int32_t SPVM__Sys__IO__freopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
-  errno = 0;
   FILE* reopened_stream = freopen(path, mode, stream);
   
   if (!reopened_stream) {
@@ -1537,7 +1496,6 @@ int32_t SPVM__Sys__IO__setvbuf(SPVM_ENV* env, SPVM_VALUE* stack) {
     }
   }
   
-  errno = 0;
   int32_t status = setvbuf(stream, buf, mode, size);
   if (!(status == 0)) {
     env->die(env, stack, "[System Error]setvbuf failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
@@ -1666,3 +1624,132 @@ int32_t SPVM__Sys__IO__utimes(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 }
 
+int32_t SPVM__Sys__IO__popen(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if defined(_WIN32)
+  env->die(env, stack, "popen is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
+  int32_t error_id = 0;
+  
+  void* obj_command = stack[0].oval;
+  if (!obj_command) {
+    return env->die(env, stack, "$command must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  const char* command = env->get_chars(env, stack, obj_command);
+  
+  void* obj_type = stack[1].oval;
+  
+  if (!obj_type) {
+    return env->die(env, stack, "$type must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  const char* type = env->get_chars(env, stack, obj_type);
+  
+  FILE* stream = popen(command, type);
+  
+  if (!stream) {
+    env->die(env, stack, "[System Error]popen failed:%s.", env->strerror(env, stack, errno, 0), command, __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
+  
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_close", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
+  
+  stack[0].oval = obj_stream;
+  
+  return 0;
+#endif
+}
+
+int32_t SPVM__Sys__IO___popen(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if !defined(_WIN32)
+  env->die(env, stack, "_popen is not supported in this system(!defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
+  int32_t error_id = 0;
+  
+  void* obj_command = stack[0].oval;
+  if (!obj_command) {
+    return env->die(env, stack, "$command must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  const char* command = env->get_chars(env, stack, obj_command);
+  
+  void* obj_type = stack[1].oval;
+  
+  if (!obj_type) {
+    return env->die(env, stack, "$type must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  const char* type = env->get_chars(env, stack, obj_type);
+  
+  FILE* stream = _popen(command, type);
+  
+  if (!stream) {
+    env->die(env, stack, "[System Error]_popen failed:%s.", env->strerror(env, stack, errno, 0), command, __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  void* obj_stream = env->new_pointer_object_by_name(env, stack, "Sys::IO::FileStream", stream, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
+  
+  env->set_field_byte_by_name(env, stack, obj_stream, "no_close", 1, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
+  
+  stack[0].oval = obj_stream;
+  
+  return 0;
+#endif
+}
+
+int32_t SPVM__Sys__IO__pclose(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if defined(_WIN32)
+  env->die(env, stack, "pclose is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
+  int32_t error_id = 0;
+  
+  void* obj_stream = stack[0].oval;
+  if (!obj_stream) {
+    return env->die(env, stack, "$stream must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  FILE* stream = env->get_pointer(env, stack, obj_stream);
+  
+  int32_t status = pclose(stream);
+  
+  if (status == -1) {
+    env->die(env, stack, "[System Error]pclose failed:%s.", env->strerror(env, stack, errno, 0), stream, __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+#endif
+}
+
+int32_t SPVM__Sys__IO___pclose(SPVM_ENV* env, SPVM_VALUE* stack) {
+#if !defined(_WIN32)
+  env->die(env, stack, "_pclose is not supported in this system(!defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
+  int32_t error_id = 0;
+  
+  void* obj_stream = stack[0].oval;
+  if (!obj_stream) {
+    return env->die(env, stack, "$stream must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  FILE* stream = env->get_pointer(env, stack, obj_stream);
+  
+  int32_t status = _pclose(stream);
+  
+  if (status == -1) {
+    env->die(env, stack, "[System Error]_pclose failed:%s.", env->strerror(env, stack, errno, 0), stream, __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+#endif
+}
