@@ -93,6 +93,22 @@ int32_t SPVM__Sys__Process__sleep(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
+int32_t SPVM__Sys__Process__usleep(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int64_t usec = stack[0].lval;
+  
+  int32_t status = usleep(usec);
+  
+  if (status == -1) {
+    env->die(env, stack, "[System Error]usleep failed.", __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+}
+
 int32_t SPVM__Sys__Process__wait(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
   env->die(env, stack, "wait is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
@@ -150,9 +166,14 @@ int32_t SPVM__Sys__Process__system(SPVM_ENV* env, SPVM_VALUE* stack) {
     command = env->get_chars(env, stack, obj_command);
   }
   
-  int32_t status = system(command);
+  int32_t wstatus = system(command);
   
-  stack[0].ival = status;
+  if (wstatus == -1) {
+    env->die(env, stack, "[System Error]system failed:%s", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
+  }
+  
+  stack[0].ival = wstatus;
   
   return 0;
 }
@@ -318,6 +339,10 @@ int32_t SPVM__Sys__Process__execv(SPVM_ENV* env, SPVM_VALUE* stack) {
   const char* path = env->get_chars(env, stack, obj_path);
   
   void* obj_args = stack[1].oval;
+  if (!obj_args) {
+    return env->die(env, stack, "$args must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
   char** argv;
   int32_t args_length = 0;
   if (obj_args) {
@@ -325,13 +350,16 @@ int32_t SPVM__Sys__Process__execv(SPVM_ENV* env, SPVM_VALUE* stack) {
     argv = env->new_memory_block(env, stack, sizeof(char*) * (args_length + 1));
     for (int32_t i = 0; i < args_length; i++) {
       void* obj_arg = env->get_elem_object(env, stack, obj_args, i);
+      
+      if (!obj_arg) {
+        return env->die(env, stack, "The %dth element of $args must be defined.", i, __func__, FILE_NAME, __LINE__);
+      }
+      
       char* arg = (char*)env->get_chars(env, stack, obj_arg);
       argv[i] = arg;
     }
   }
-  else {
-    argv = env->new_memory_block(env, stack, sizeof(char*) * 1);
-  }
+  
   assert(argv[args_length] == NULL);
   
   int32_t status = execv(path, argv);
@@ -444,19 +472,3 @@ int32_t SPVM__Sys__Process__WIFCONTINUED(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 }
 
-int32_t SPVM__Sys__Process__usleep(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int64_t usec = stack[0].lval;
-  
-  int32_t status = usleep(usec);
-
-  if (status == -1) {
-    env->die(env, stack, "[System Error]usleep failed.", __func__, FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
-  }
-
-  stack[0].ival = status;
-  
-  return 0;
-}
-
